A small driver for Texas Instruments battery gauges (written for BQ27427)
Modules
- known_
chips - This module is tested on BQ27427, but I suspect that the interface and commands are pretty similar across all TI bridges. YMMV
- memory
- Besides regular commands and control commands there is also direct memory access using datablocks. Some vital parameters (e.g programmed battery capacity) are available exclusively through this interface.
Structs
- Bq27xx
- Chip handle